@@ -1,5 +1,5 @@
 /* Test the dispatcher.
-   Copyright (C) 2002-2003  Bruno Haible <bruno@clisp.org>
+   Copyright (C) 2002-2005  Bruno Haible <bruno@clisp.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,8 +25,8 @@
 
 static sigsegv_dispatcher dispatcher;
 
-static unsigned int logcount = 0;
-static unsigned long logdata[10];
+static volatile unsigned int logcount = 0;
+static volatile unsigned long logdata[10];
 
 static int
 area_handler (void *fault_address, void *user_arg)
@@ -79,7 +79,11 @@ main ()
     }
   area1 = (unsigned long) p;
   sigsegv_register (&dispatcher, (void *) area1, 0x4000, &area_handler, &area1);
-  mprotect ((void *) area1, 0x4000, PROT_NONE);
+  if (mprotect ((void *) area1, 0x4000, PROT_NONE) < 0)
+    {
+      fprintf (stderr, "mprotect failed.\n");
+      exit (2);
+    }
 
   p = mmap_zeromap ((void *) 0x0BEE0000, 0x4000);
   if (p == (void *)(-1))
@@ -89,7 +93,17 @@ main ()
     }
   area2 = (unsigned long) p;
   sigsegv_register (&dispatcher, (void *) area2, 0x4000, &area_handler, &area2);
-  mprotect ((void *) area2, 0x4000, PROT_READ);
+  if (mprotect ((void *) area2, 0x4000, PROT_READ) < 0)
+    {
+      fprintf (stderr, "mprotect failed.\n");
+      exit (2);
+    }
+  if (mprotect ((void *) area2, 0x4000, PROT_READ_WRITE) < 0
+      || mprotect ((void *) area2, 0x4000, PROT_READ) < 0)
+    {
+      fprintf (stderr, "mprotect failed.\n");
+      exit (2);
+    }
 
   p = mmap_zeromap ((void *) 0x06990000, 0x4000);
   if (p == (void *)(-1))
